Crate rustad

Crate rustad 

A rust Automatic Differentiation library

This library is Under Construction and its API is not stable; see its readme file

Re-exports

pub use numvec::NumVec;
pub use ad::AD;
pub use ad::ad_from_value;
pub use ad::ad_from_vector;
pub use ad::ad_to_vector;
pub use ad::doc_generic_v;
pub use adfn::ADfn;
pub use adfn::doc_generic_e;
pub use tape::IndexT;
pub use tape::start_recording;
pub use tape::stop_recording;
pub use atom::register_atom;
pub use atom::call_atom;
pub use atom::AtomEval;

Modules

ad
This module defines the automatic differentiation class AD<V>.
adfn
AD function objects
atom
This module implements AD atomic functions
numvec
This module defines the numeric vector class NumVec < S >.
tape
Define tape objects
utility
Some utilities not specific to implementing the rustd package

Structs

OpInfo
Information for one operator

Constants

YEAR_MONTH_DAY
is the date corresponding to this version of the software as year.month.day .

Traits

AtomEvalVecPublic
This is the public interface to a sealed trait
ThisThreadTapePublic
This is the public interface to a sealed trait