doc_generic_e

Function doc_generic_e 

pub fn doc_generic_e()
Documentation for the rustad generic type parameter E.

This is the type used to evaluate ADfn member functions with names that begin with forward or reverse .

  • If a member function name ends with _value , E is the same as V; see doc_generic_v and AD.

  • If a member function name ends with _ad , E is the same as AD < V >; see doc_generic_v and AD.

Note that V evaluations are used to compute values and AD<V> evaluations are used to build new ADfn objects.